@@ -1,4 +1,4 @@
-# Copyright (c) 2003-2017 CORE Security Technologies
+# SECUREAUTH LABS. Copyright 2018 SecureAuth Corporation. All rights reserved.
 #
 # This software is provided under under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
@@ -11,7 +11,7 @@
 #
 #   Best way to learn how to use these calls is to grab the protocol standard
 #   so you understand what the call does, and then read the test case located
-#   at https://github.com/CoreSecurity/impacket/tree/master/impacket/testcases/SMB_RPC
+#   at https://github.com/SecureAuthCorp/impacket/tree/master/tests/SMB_RPC
 #
 #   Some calls have helper functions, which makes it even easier to use.
 #   They are located at the end of this file.
@@ -441,15 +441,15 @@ class DHCP_OPTION_ELEMENT_UNION(NDRUNION):
         ('tag', DHCP_OPTION_DATA_TYPE),
     )
     union = {
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpByteOption            : ('ByteOption', BYTE),
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpWordOption            : ('WordOption', WORD),
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpDWordOption           : ('DWordOption', DWORD),
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpDWordDWordOption      : ('DWordDWordOption', DWORD_DWORD),
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpIpAddressOption       : ('IpAddressOption', DHCP_IP_ADDRESS),
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpStringDataOption      : ('StringDataOption', LPWSTR),
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpBinaryDataOption      : ('BinaryDataOption', DHCP_BINARY_DATA),
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpEncapsulatedDataOption: ('EncapsulatedDataOption', DHCP_BINARY_DATA),
-        DHCP_OPTION_DATA_TYPE.enumItems.DhcpIpv6AddressOption     : ('Ipv6AddressDataOption', LPWSTR),
+        DHCP_OPTION_DATA_TYPE.DhcpByteOption            : ('ByteOption', BYTE),
+        DHCP_OPTION_DATA_TYPE.DhcpWordOption            : ('WordOption', WORD),
+        DHCP_OPTION_DATA_TYPE.DhcpDWordOption           : ('DWordOption', DWORD),
+        DHCP_OPTION_DATA_TYPE.DhcpDWordDWordOption      : ('DWordDWordOption', DWORD_DWORD),
+        DHCP_OPTION_DATA_TYPE.DhcpIpAddressOption       : ('IpAddressOption', DHCP_IP_ADDRESS),
+        DHCP_OPTION_DATA_TYPE.DhcpStringDataOption      : ('StringDataOption', LPWSTR),
+        DHCP_OPTION_DATA_TYPE.DhcpBinaryDataOption      : ('BinaryDataOption', DHCP_BINARY_DATA),
+        DHCP_OPTION_DATA_TYPE.DhcpEncapsulatedDataOption: ('EncapsulatedDataOption', DHCP_BINARY_DATA),
+        DHCP_OPTION_DATA_TYPE.DhcpIpv6AddressOption     : ('Ipv6AddressDataOption', LPWSTR),
     }
 
 class DHCP_OPTION_DATA_ELEMENT(NDRSTRUCT):
@@ -518,7 +518,7 @@ class LPOPTION_VALUES_ARRAY(NDRPOINTER):
         ('Data', OPTION_VALUES_ARRAY),
     )
 
-class DHCP_ALL_OPTION_VALUES(NDRSTRUCT):
+class DHCP_ALL_OPTIONS_VALUES(NDRSTRUCT):
     structure = (
         ('Flags', DWORD),
         ('NumElements', DWORD),
@@ -527,7 +527,7 @@ class DHCP_ALL_OPTION_VALUES(NDRSTRUCT):
 
 class LPDHCP_ALL_OPTION_VALUES(NDRPOINTER):
     referent = (
-        ('Data', DHCP_ALL_OPTION_VALUES),
+        ('Data', DHCP_ALL_OPTIONS_VALUES),
     )
 
 ################################################################################
@@ -888,7 +888,7 @@ def hDhcpGetOptionValueV5(dce, option_id, flags=DHCP_FLAGS_OPTION_DEFAULT, class
     request['ClassName'] = classname
     request['VendorName'] = vendorname
     request['ScopeInfo']['ScopeType'] = scopetype
-    request['ScopeInfo']['ScopeInfo']['tag'] = scopetype.value
+    request['ScopeInfo']['ScopeInfo']['tag'] = scopetype
     if scopetype == DHCP_OPTION_SCOPE_TYPE.DhcpSubnetOptions:
         request['ScopeInfo']['ScopeInfo']['SubnetScopeInfo'] = options
     elif scopetype == DHCP_OPTION_SCOPE_TYPE.DhcpReservedOptions:
