@@ -1213,6 +1213,19 @@ class DRSBindResponse(NDRCALL):
         ('ErrorCode',DWORD),
     )
 
+# 4.1.25 IDL_DRSUnbind (Opnum 1)
+class DRSUnbind(NDRCALL):
+    opnum = 1
+    structure = (
+        ('phDrs', DRS_HANDLE),
+    )
+
+class DRSUnbindResponse(NDRCALL):
+    structure = (
+        ('phDrs', DRS_HANDLE),
+        ('ErrorCode',DWORD),
+    )
+
 # 4.1.10 IDL_DRSGetNCChanges (Opnum 3)
 class DRSGetNCChanges(NDRCALL):
     opnum = 3
@@ -1297,6 +1310,7 @@ class DRSDomainControllerInfoResponse(NDRCALL):
 ################################################################################
 OPNUMS = {
  0 : (DRSBind,DRSBindResponse ),
+ 1 : (DRSUnbind,DRSUnbindResponse ),
  3 : (DRSGetNCChanges,DRSGetNCChangesResponse ),
  12: (DRSCrackNames,DRSCrackNamesResponse ),
  16: (DRSDomainControllerInfo,DRSDomainControllerInfoResponse ),
@@ -1314,6 +1328,11 @@ def checkNullString(string):
     else:
         return string
 
+def hDRSUnbind(dce, hDrs):
+    request = DRSUnbind()
+    request['phDrs'] = hDrs
+    return dce.request(request)
+
 def hDRSDomainControllerInfo(dce, hDrs, domain, infoLevel):
     request = DRSDomainControllerInfo()
     request['hDrs'] = hDrs
