@@ -221,6 +221,19 @@ def activeConnectionsWatcher(server):
             server.activeRelays[target][port]['data'] = data
             # Let's store the protocol scheme, needed be used later when trying to find the right socks relay server to use
             server.activeRelays[target][port]['scheme'] = scheme
+
+            # Default values in case somebody asks while we're gettting the data
+            server.activeRelays[target][port][userName]['isAdmin'] = 'N/A'
+            # Do we have admin access in this connection?
+            try:
+                LOG.debug("Checking admin status for user %s" % str(userName))
+                isAdmin = client.isAdmin()
+                server.activeRelays[target][port][userName]['isAdmin'] = isAdmin
+            except Exception as e:
+                # Method not implemented
+                server.activeRelays[target][port][userName]['isAdmin'] = 'N/A'
+                pass
+            LOG.debug("isAdmin returned: %s" % server.activeRelays[target][port][userName]['isAdmin'])
         else:
             LOG.info('Relay connection for %s at %s(%d) already exists. Discarding' % (userName, target, port))
             client.killConnection()
@@ -246,7 +259,8 @@ def webService(server):
                 for user in server.activeRelays[target][port]:
                     if user != 'data' and user != 'scheme':
                         protocol = server.activeRelays[target][port]['scheme']
-                        relays.append([protocol, target, user, str(port)])
+                        isAdmin = server.activeRelays[target][port][user]['isAdmin']
+                        relays.append([protocol, target, user, isAdmin, str(port)])
         return jsonify(relays)
 
     @app.route('/ntlmrelayx/api/v1.0/relays', methods=['GET'])
